package com.waimai.web.admin.service;

import java.util.List;
import com.waimai.web.admin.domain.Orders;

/**
 * 订单记录Service接口
 * 
 * @author callmeyan
 * @date 2023-03-24
 */
public interface IOrdersService 
{
    /**
     * 查询订单记录
     * 
     * @param id 订单记录主键
     * @return 订单记录
     */
    public Orders selectOrdersById(String id);

    /**
     * 查询订单记录列表
     * 
     * @param orders 订单记录
     * @return 订单记录集合
     */
    public List<Orders> selectOrdersList(Orders orders);

    /**
     * 新增订单记录
     * 
     * @param orders 订单记录
     * @return 结果
     */
    public int insertOrders(Orders orders);

    /**
     * 修改订单记录
     * 
     * @param orders 订单记录
     * @return 结果
     */
    public int updateOrders(Orders orders);

    /**
     * 批量删除订单记录
     * 
     * @param ids 需要删除的订单记录主键集合
     * @return 结果
     */
    public int deleteOrdersByIds(String[] ids);

    /**
     * 删除订单记录信息
     * 
     * @param id 订单记录主键
     * @return 结果
     */
    public int deleteOrdersById(String id);
}
